run

package
v0.0.0-...-7dfe24e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2026 License: GPL-3.0, GPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var NoEditorError = errors.New("$EDITOR not set")

Functions

func Edit

func Edit(t model.Target, src *model.Source) *spool.ExitCode

func Exec

func Exec(source *model.Source, target model.Target, args ...string) error

func ExecWithTrigger

func ExecWithTrigger(source *model.Source, target model.Target, tag *model.Tag) error

ExecWithTrigger loops through a model.Source and runs targets if they match the expected model.Tag triggers only run if their subdirectory is "in tree"

func Final

func Final(source *model.Source, target model.Target) error

func Post

func Post(source *model.Source, target model.Target) error

func Pre

func Pre(source *model.Source, target model.Target) error

func Run

func Run(source *model.Source, target model.Target, args ...string) error

Run creates an exec.Cmd from a model.Source, model.Target and args. 1. run pre-triggers, quit on fail 2. run target 3. if success, run post 4. run final

Types

This section is empty.

Jump to