Documentation
¶
Index ¶
- Variables
- func Edit(t model.Target, src *model.Source) *spool.ExitCode
- func Exec(source *model.Source, target model.Target, args ...string) error
- func ExecWithTrigger(source *model.Source, target model.Target, tag *model.Tag) error
- func Final(source *model.Source, target model.Target) error
- func Post(source *model.Source, target model.Target) error
- func Pre(source *model.Source, target model.Target) error
- func Run(source *model.Source, target model.Target, args ...string) error
Constants ¶
This section is empty.
Variables ¶
var NoEditorError = errors.New("$EDITOR not set")
Functions ¶
func ExecWithTrigger ¶
ExecWithTrigger loops through a model.Source and runs targets if they match the expected model.Tag triggers only run if their subdirectory is "in tree"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.